### Empty code block and empty non-code, non-output block

Example Markdown file with an empty Python fenced code block.

```python
```

Expected output-

```
non-empty expected output
```


Empty code block that has no output block

```python
```


Empty block that isn't a code or output block
```text
```